@@ -1,28 +1,18 @@
 import os
-import re
 
 from typing import List
 
 
-""" Migrate from 0.1.3 to 1.0.0.
+""" Migrate from 2.0.2 to 2.0.3
 
 This script will do the following changes :
-- Replace `quotecast` module with `degiro_connector.quotecast`
-- Replace `trading` module with `degiro_connector.trading`
 
-If files might require manual update it will list those files.
+1/
+REPLACE `orderId`
+WITH    `order_id`
 """
 
 
-def need_manual_update(file_source: str) -> bool:
-    x = re.search(
-        pattern=r"(quotecast|trading)\s*=\s*[A-Z]",
-        string=file_source,
-    )
-
-    return x is not None
-
-
 def get_files_list(root_path=".") -> List[str]:
     files_list = list()
 
@@ -42,8 +32,6 @@ def get_files_list(root_path=".") -> List[str]:
 
 
 def process(files_list: List[str]):
-    manual_update_list = list()
-
     print("Processing the following files : ")
 
     for file_path in files_list:
@@ -52,18 +40,11 @@ def process(files_list: List[str]):
                 file_source = f.read()
                 replace_string = file_source
                 replace_string = replace_string.replace(
-                    " quotecast.",
-                    " degiro_connector.quotecast.",
-                )
-                replace_string = replace_string.replace(
-                    " trading.",
-                    " degiro_connector.trading.",
+                    "orderId",
+                    "order_id",
                 )
 
-                if need_manual_update(file_source):
-                    print("UNCHANGED :", file_path)
-                    manual_update_list.append(file_path)
-                elif replace_string != file_source:
+                if replace_string != file_source:
                     print("CHANGED   :", file_path)
                     f.seek(0)
                     f.write(replace_string)
@@ -71,11 +52,6 @@ def process(files_list: List[str]):
                 else:
                     print("UNCHANGED :", file_path)
 
-    if len(manual_update_list) > 0:
-        print("The following files might need a manual update :")
-        for file_path in manual_update_list:
-            print(file_path)
-
 
 files_list = get_files_list(root_path=".")
 process(files_list=files_list)
