@@ -38,8 +38,11 @@ class ActionGetAccountInfo(AbstractAction):
             response_raw.raise_for_status()
             response_dict = response_raw.json()
         except requests.HTTPError as e:
-            logger.fatal(response_raw.status_code)
-            logger.fatal(response_raw.text)
+            status_code = getattr(response_raw, "status_code", "No status_code found.")
+            text = getattr(response_raw, "text", "No text found.")
+            logger.fatal(status_code)
+            logger.fatal(text)
+            return None
         except Exception as e:
             logger.fatal(e)
             return None
