@@ -134,10 +134,10 @@ class ActionProductSearch(AbstractAction):
         params = cls.product_search_request_to_api(
             request=request,
         )
-        
+
         if credentials.int_account > 0:
             params["intAccount"] = credentials.int_account
-        
+
         params["sessionId"] = session_id
 
         http_request = requests.Request(method="GET", url=url, params=params)
@@ -156,8 +156,11 @@ class ActionProductSearch(AbstractAction):
                     payload=response_dict,
                 )
         except requests.HTTPError as e:
-            logger.fatal(response_raw.status_code)
-            logger.fatal(response_raw.text)
+            status_code = getattr(response_raw, "status_code", "No status_code found.")
+            text = getattr(response_raw, "text", "No text found.")
+            logger.fatal(status_code)
+            logger.fatal(text)
+            return None
         except Exception as e:
             logger.fatal(e)
             return None
